/*
 * $Id: BalloonTip.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "BalloonTip.h"

#include <qpe/config.h>
#include <qtimer.h>
#include <qpainter.h>

void BalloonTip::showTip(QWidget* parent, QString message, QPoint pos, int
    displaySecs, int startShow, int numShows, QString configName, QString
    configGroup, QString configEntry)
{
    if (!checkDisplay(configName, configGroup, configEntry, numShows,
                      startShow))
    {
        return;
    }

    BalloonTip* bt = new BalloonTip(parent, message, pos, displaySecs);
    bt->show();
}

BalloonTip::BalloonTip(QWidget* parent, QString i_message, QPoint bubblePos, 
                       int displaySecs) :
    QWidget(parent, 0, 0)
{
    message = i_message;
    setBoundingRect();
    QRect pos = boundingRect;
    pos.moveTopLeft(bubblePos);
    setGeometry(pos);
    QTimer::singleShot(1000 * displaySecs, this, SLOT(timerFired()));
}

BalloonTip::~BalloonTip()
{
}

void BalloonTip::timerFired()
{
    if (isVisible())
    {
        close();
    }
}

void BalloonTip::setBoundingRect()
{
    QPainter p(this);

    boundingRect = p.boundingRect(((QWidget*)parent())->rect(), 0, 
                                        message);
    boundingRect.setWidth(boundingRect.width() + 4);
    boundingRect.setHeight(boundingRect.height() + 4);
}

void BalloonTip::paintEvent(QPaintEvent* pe)
{
    QPainter p(this);
    p.setPen(QPen(QColor(0,0,0), 1, Qt::SolidLine, Qt::RoundCap, 
                  Qt::RoundJoin));
    p.setBrush(QColor(255,255,0));
    p.drawRect(boundingRect);
    p.drawText(boundingRect.left() + 2, boundingRect.top() + 2, 
               boundingRect.width(), boundingRect.height(), 0, message);
}

bool BalloonTip::checkDisplay(QString configName, QString configGroup,
                              QString configEntry, int numShows, int
                              startShow)
{
    if (configName.isEmpty() || configGroup.isEmpty() || configEntry.isEmpty())
        return true;

    Config config(configName);
    config.setGroup(configGroup);
    int numShowsDone = config.readNumEntry(configEntry, 0); 
    if (numShowsDone >= numShows)
        return false;

    numShowsDone++;
    config.writeEntry(configEntry, numShowsDone);

    if (numShowsDone >= startShow) 
        return true;
    else
        return false;
}

