/*
 * $Id: CategoryEdit.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "CategoryEdit.h"
#include "TimeSleuthDocument.h"

#include <qlist.h>
#include <qmessagebox.h>
#include <qlineedit.h>

CategoryEdit::CategoryEdit(ActivityCategory* c, TimeSleuthDocument* doc, 
    QWidget* parent, const char* name, bool modal, WFlags fl) :
    CategoryEditBase(parent, name, modal, fl), category(c), document(doc)
{
    setupCategory(); 
}

CategoryEdit::~CategoryEdit()
{
}

void CategoryEdit::setupCategory()
{
    if (category)
    {
        txtName->setText(category->name);
    }
}

void CategoryEdit::accept()
{
    QString name = txtName->text().stripWhiteSpace();
    
    if ((name == "--sync--") || (name == "--start--") || 
        (name == "--end--"))
    {
        QMessageBox::warning(this, 
            tr("Category Error"),
            tr("This name is not valid.\n"
               "Please select another."),
            QMessageBox::Ok, 0);
        return;
    }
    
    if (name.isEmpty())
    {
        QMessageBox::warning(this, tr("Category Error"), 
            tr("Category must have a name"), QMessageBox::Ok, 0);
        return;
    }

    QListIterator<ActivityCategory> li(document->activityCategories);
    for( ; li.current(); ++li)
    {
        ActivityCategory* c = li.current();
        if ((c != category) && 
            (c->name == name) &&
            (!c->deleted))
        {
            QMessageBox::warning(this, tr("Category Error"), 
                tr("Category name must be unique"), QMessageBox::Ok, 0);
            return;
        }
    }

    CategoryEditBase::accept();
}

