/*
 * $Id: OperatingMode.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "OperatingMode.h"

#include <qradiobutton.h>
#include <qlineedit.h>
#include <qmessagebox.h>

OperatingMode::OperatingMode(QWidget* parent, const char* name, 
    bool modal, WFlags fl) : OperatingModeBase(parent, name, modal, fl)
{
    connect(radPersonal, SIGNAL(toggled(bool)), this, SLOT(modeToggled(bool)));
}

OperatingMode::~OperatingMode()
{
}

void OperatingMode::modeToggled(bool personal)
{
    if (personal)
    {
        txtServer->setEnabled(false);
        txtUserID->setEnabled(false);
        txtPassword->setEnabled(false);
    }
    else
    {
        txtServer->setEnabled(true);
        txtUserID->setEnabled(true);
        txtPassword->setEnabled(true);
    }
}

void OperatingMode::accept()
{
    if (radGroup->isChecked())
    {
        QString server = txtServer->text().stripWhiteSpace();
        QString userID = txtUserID->text().stripWhiteSpace();
        QString password = txtPassword->text().stripWhiteSpace();

        if (server.right(1) == "/")
            server = server.left(server.length() - 1);
    
        if (server == "" || userID == "" || password == "")
        {
            QMessageBox::warning(this, 
                tr("Operating Mode Error"),
                tr("You must enter a server,\n"
                   "username and password."),
                QMessageBox::Ok, 0);
            return;
        }
    
        if ((userID == "--sync--") || (userID == "--start--") || 
            (userID == "--end--"))
        {
            QMessageBox::warning(this, 
                tr("Operating Mode Error"),
                tr("This username is not valid.\n"
                   "Please select another."),
                QMessageBox::Ok, 0);
            return;
        }
    
        if ((password == "--sync--") || (password == "--start--") || 
            (password == "--end--"))
        {
            QMessageBox::warning(this, 
                tr("Operating Mode Error"),
                tr("This password is not valid.\n"
                   "Please select another."),
                QMessageBox::Ok, 0);
            return;
        }

        txtServer->setText(server);
        txtUserID->setText(userID);
        txtPassword->setText(password);
    }
    
    OperatingModeBase::accept();
}
