/*
 * $Id: PeriodReport.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "PeriodReport.h"
#include "TimeSleuthDocument.h"
#include "TimeSleuthMainWindow.h"
#include "ReportParams1.h"

#include <qdatetime.h>
#include <qstring.h>
#include <qwidget.h>
#include <qlist.h>
#include <qcheckbox.h>
#include <stdio.h>

PeriodReport::PeriodReport(QWidget* owner, 
    TimeSleuthDocument* document) : Report(owner, document)
{
    fromDate = TimeSleuthMainWindow::getTSTime().date();
    toDate = fromDate;
    includeZeroTimeActivities = true;
    decimalHours = false;
}

PeriodReport::~PeriodReport()
{
}

bool PeriodReport::setParametersFromUI()
{
    ReportParams1 dlg(owner, 0, true);
    dlg.showMaximized();
    dlg.setFromDate(fromDate);
    dlg.setToDate(toDate);
    dlg.chkIncludeZeroActivities->setChecked(includeZeroTimeActivities);
    dlg.chkDecimalHours->setChecked(decimalHours);
    if (dlg.exec())
    {
        fromDate = dlg.getFromDate();
        toDate = dlg.getToDate();
        includeZeroTimeActivities = dlg.chkIncludeZeroActivities->isChecked();
        decimalHours = dlg.chkDecimalHours->isChecked();
        return true;
    }
    else
    {
        return false;
    }
}

void PeriodReport::setParametersFromString(QString params)
{
    if (params.isEmpty())
        return;

    int z, d, yf, mf, df, yt, mt, dt;

    sscanf(params.latin1(), "%d,%d,%d,%d,%d,%d,%d,%d",
           &z, &d, &yf, &mf, &df, &yt, &mt, &dt);

    includeZeroTimeActivities = z ? true : false;
    decimalHours = d ? true : false;
    fromDate.setYMD(yf, mf, df);
    toDate.setYMD(yt, mt, dt);
}

QString PeriodReport::getParameters()
{
    return QString().sprintf("%d,%d,%d,%d,%d,%d,%d,%d",
        includeZeroTimeActivities ? 1 : 0,
        decimalHours ? 1: 0,
        fromDate.year(), fromDate.month(), fromDate.day(),
        toDate.year(), toDate.month(), toDate.day());
}

