/*
 * $Id: PeriodSummaryReport.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "PeriodSummaryReport.h"
#include "TimeSleuthDocument.h"
#include "TimeSleuthMainWindow.h"
#include "ReportParams1.h"

#include <qdatetime.h>
#include <qstring.h>
#include <qwidget.h>
#include <qlist.h>
#include <qcheckbox.h>
#include <stdio.h>
#include <qpe/timestring.h>

PeriodSummaryReport::PeriodSummaryReport(QWidget* owner, 
    TimeSleuthDocument* document) : PeriodReport(owner, document)
{
}

PeriodSummaryReport::~PeriodSummaryReport()
{
}

QString PeriodSummaryReport::getMenuName()
{
    return QString(tr("Period Summary Report"));
}

QString PeriodSummaryReport::getReportText()
{
    QString s;
    bool warnOpenTasks = false;
    bool showingDeleted = false;

    // Title
    s += "<qt bgcolor=#ffffff>";
    s += "<p><font face=Arial size=5 color=#0000ff>";
    s += getMenuName();
    s += "</font></p>";

    // Period
    s += "<p><font face=Arial size=4 color=#0000ff>";
    s += tr("%1 to %2").arg(TimeString::shortDate(fromDate)).
                        arg(TimeString::shortDate(toDate));
    s += "</font></p>";

    // Table
    s += "<table border=0 cellpadding=2 cellspacing=1>";
    s += "<tr><td rowspan=2 bgcolor=" + QString(HEADER_BGCOLOR) + 
         ">&nbsp;</td>";
    int* categoryTotals = new int[document->activityCategories.count()];
    QListIterator<ActivityCategory> cli(document->activityCategories);
    for(int i = 0; cli.current(); ++cli, ++i)
    {
        ActivityCategory* category = cli.current();
        categoryTotals[i] = 0;
        s += "<td align=center bgcolor=" + QString(HEADER_BGCOLOR) + ">";
        if (category->deleted)
        {
            showingDeleted = true;
            s += "<font color=#ff0000><i>";
        }
        s += category->name;    // TODO urlencode
        if (category->deleted)
        {
            s += "</i></font>";
        }
        s += "</td>";
    }
    s += "</tr>";
    s += "<tr>";
    for(unsigned int i = 0; i < document->activityCategories.count(); ++i)
    {
        s += "<td align=center bgcolor=" + QString(HEADER_BGCOLOR) + ">";
        s += "<font size=-1>";
        if (decimalHours)
            s += tr("hours");
        else
            s += tr("hrs&nbsp;:&nbsp;mins");
        s += "</font>";
        s += "</td>";
    }
    s += "</tr>";
    QListIterator<Activity> ali(document->activities);
    for( ; ali.current(); ++ali)
    {
        Activity* activity = ali.current();
        bool openTasks = false;
        int minutes = document->getActivityDuration(fromDate, toDate, 
                                                    activity, &openTasks);
        if (openTasks)
            warnOpenTasks = true;

        if ((minutes > 0) || 
            (includeZeroTimeActivities && 
             (!activity->deleted || 
              document->hasActivityGotTasks(activity))))
        {
            s += "<tr><td bgcolor=";
            s += QString(HEADER_BGCOLOR) + ">";
            if (activity->deleted)
            {
                showingDeleted = true;
                s += "<font color=#ff0000><i>";
            }
            s += activity->name; // TODO urlencode
            if (activity->deleted)
                s += "</i></font>";
            s += "</td>"; 
            cli.toFirst();
            for(int i = 0; cli.current(); ++cli, ++i)
            {
                s += "<td align=center bgcolor=" + QString(DATA_BGCOLOR) + ">";
                ActivityCategory* category = cli.current();
                if (activity->category == category)
                {
                    categoryTotals[i] += minutes;
                    QString time;
                    if (decimalHours)
                        time.sprintf("%5.4f", minutes / 60.0);
                    else
                        time.sprintf("%d:%02d", minutes / 60, minutes % 60);
                    s += time;
                }
                else
                {
                    s += "&nbsp;";
                }
                s += "</td>";
            }
            s += "</tr>";
        }
    }

    s += "<tr><td bgcolor=" + QString(HEADER_BGCOLOR) + ">" +
         tr("Totals") + "</td>";
    for(unsigned int i = 0; i < document->activityCategories.count(); i++)
    {
        s += "<td align=center bgcolor=" + QString(TOTALS_BGCOLOR) + ">";
        QString time;
        if (decimalHours)
            time.sprintf("%5.4f", categoryTotals[i] / 60.0);
        else
            time.sprintf("%d:%02d", categoryTotals[i] / 60,
            categoryTotals[i] % 60);
         s += time;
         s += "</td>";
    }
    s += "</tr>"; 
    s += "</table>";

    if (categoryTotals)
        delete[] categoryTotals;

    if (showingDeleted)
    {
        s += "<p><font color=#ff0000>";
        s += tr("Activities and categories shown in<br>"
                "<i>red italics</i> are obsolete.");
        s += "</font></p>";
    }
    
    if (warnOpenTasks)
    {
        s += "<p><font color=#ff0000>";
        s += tr("There are <i>active</i> tasks in this time period<br>"
                "that are excluded from this report.");
        s += "</font></p>";
    }

    s += "</qt>";

    return s;
}

QString PeriodSummaryReport::getReportFileName()
{
    QDate now = TimeSleuthMainWindow::getTSTime().date();

    return tr("Summary %1").arg(TimeString::shortDate(now)); 
}

