/*
 * $Id: PeriodTimeSheetReport.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "PeriodTimeSheetReport.h"
#include "TimeSleuthDocument.h"
#include "TimeSleuthMainWindow.h"
#include "ReportParams1.h"

#include <qdatetime.h>
#include <qstring.h>
#include <qwidget.h>
#include <qlist.h>
#include <qcheckbox.h>
#include <stdio.h>
#include <qpe/timestring.h>

PeriodTimeSheetReport::PeriodTimeSheetReport(QWidget* owner, 
    TimeSleuthDocument* document) : PeriodReport(owner, document)
{
}

PeriodTimeSheetReport::~PeriodTimeSheetReport()
{
}

QString PeriodTimeSheetReport::getMenuName()
{
    return QString(tr("Period Time Sheet"));
}

QString PeriodTimeSheetReport::getReportText()
{
    QString s;
    bool warnOpenTasks = false;
    bool showingDeleted = false;

    // Title
    s += "<qt bgcolor=#ffffff>";
    s += "<p><font face=Arial size=5 color=#0000ff>";
    s += getMenuName();
    s += "</font></p>";

    // Period
    s += "<p><font face=Arial size=4 color=#0000ff>";
    s += tr("%1 to %2").arg(TimeString::shortDate(fromDate)).
                        arg(TimeString::shortDate(toDate));
    s += "</font></p>";

    // Table
    s += "<table border=0 cellpadding=2 cellspacing=1>";
    s += "<tr><td colspan=2 rowspan=2 bgcolor=" + QString(HEADER_BGCOLOR) + 
         ">&nbsp;</td>";
    int* categoryDayTotals = new int[document->activityCategories.count()];
    int* categoryPeriodTotals = new int[document->activityCategories.count()];
    QListIterator<ActivityCategory> cli(document->activityCategories);
    for(int i = 0; cli.current(); ++cli, ++i)
    {
        ActivityCategory* category = cli.current();
        categoryDayTotals[i] = 0;
        categoryPeriodTotals[i] = 0;
        s += "<td align=center bgcolor=" + QString(HEADER_BGCOLOR) + ">";
        if (category->deleted)
        {
            showingDeleted = true;
            s += "<font color=#ff0000><i>";
        }
        s += category->name;    // TODO urlencode
        if (category->deleted)
            s += "</i></font>";
        s += "</td>";
    }
    s += "<td rowspan=2 bgcolor=" + QString(HEADER_BGCOLOR) + ">&nbsp;</td>";
    s += "</tr><tr>";
    for(unsigned int i = 0; i < document->activityCategories.count(); ++i)
    {
        s += "<td align=center bgcolor=" + QString(HEADER_BGCOLOR) + ">";
        s += "<font size=-1>";
        if (decimalHours)
            s += tr("hours");
        else
            s += tr("hrs&nbsp;:&nbsp;mins");
        s += "</font>";
        s += "</td>";
    }
    s += "</tr>";

    for(QDate d = fromDate; d <= toDate; d = d.addDays(1))
    {
        // If 'includeZeroTimeActivities' is true, show all non-deleted
        // activities, and those delete activities that have tasks still 
        // associated with then.
        //
        // If 'includeZeroTimeActivities' is false, show all non-deleted tasks
        // with task durations > 0, and those deleted activities that have
        // task durations > 0 (basically all activities with task durations
        // > 0).
        int nDayRows = (includeZeroTimeActivities ? 
                document->getNumActiveActivities(true) : countNonzeroActivities(d)) + 1;
        
        s += "<tr>";
        s += "<td align=top bgcolor=" + QString(HEADER_BGCOLOR);
        s += " rowspan=" + QString::number(nDayRows);
        s += ">";
        s += d.dayName(d.dayOfWeek()) + "<br>";
        s += d.monthName(d.month()) + "&nbsp;" + QString::number(d.day());
        s += "<br>";
        s += QString::number(d.year());
        s += "</td>";

        for (unsigned int i = 0; i < document->activityCategories.count(); i++)
            categoryDayTotals[i] = 0;

        QListIterator<Activity> ali(document->activities);
        bool firstActivityOfDay = true;
        for( ; ali.current(); ++ali)
        {
            Activity* activity = ali.current();
            bool openTasks = false;
            int minutes = document->getActivityDuration(d, d, activity, 
                                                    &openTasks);
            if (openTasks)
                warnOpenTasks = true;

            if ((minutes > 0) || 
                (includeZeroTimeActivities && 
                 (!activity->deleted || 
                  document->hasActivityGotTasks(activity))))
            {
                if (!firstActivityOfDay)
                    s += "<tr>";

                s += "<td bgcolor=";
                s += QString(HEADER_BGCOLOR) + ">";
                if (activity->deleted)
                {
                    showingDeleted = true;
                    s += "<font color=#ff0000><i>";
                }
                s += activity->name; // TODO urlencode
                if (activity->deleted)
                    s += "</i></font>";
                s += "</td>"; 
                cli.toFirst();
                for(int i = 0; cli.current(); ++cli, ++i)
                {
                    s += "<td align=center bgcolor=" + QString(DATA_BGCOLOR);
                    s += ">";
                    ActivityCategory* category = cli.current();
                    if (activity->category == category)
                    {
                        categoryDayTotals[i] += minutes;
                        categoryPeriodTotals[i] += minutes;
                        QString time;
                        if (decimalHours)
                            time.sprintf("%5.4f", minutes / 60.0);
                        else
                            time.sprintf("%d:%02d", minutes / 60, minutes % 60);
                        s += time;
                    }
                    else
                    {
                        s += "&nbsp;";
                    }
                    s += "</td>";
                }
                
                if (firstActivityOfDay)
                {
                    s += "<td align=center bgcolor=" + QString(DATA_BGCOLOR);
                    s += " rowspan=" + QString::number(nDayRows - 1);
                    s += ">";
                    s += "&nbsp;</td>";
                }
                
                s += "</tr>";
                
                firstActivityOfDay = false;
            }
        }

        if (!firstActivityOfDay)
            s += "<tr>";

        s += "<td bgcolor=" + QString(HEADER_BGCOLOR) + ">" +
             tr("Daily Totals") + "</td>";

        int lineTotal = 0;
        for(unsigned int i = 0; i < document->activityCategories.count(); i++)
        {
            s += "<td align=center bgcolor=" + QString(TOTALS_BGCOLOR) + ">";
            QString time;
            lineTotal += categoryDayTotals[i];
            if (decimalHours)
                time.sprintf("%5.4f", categoryDayTotals[i] / 60.0);
            else
                time.sprintf("%d:%02d", categoryDayTotals[i] / 60,
                         categoryDayTotals[i] % 60);
             s += time;
             s += "</td>";
        }

        s += "<td align=center bgcolor=" + QString(TOTALS_BGCOLOR) + ">";
        QString time;
        if (decimalHours)
            time.sprintf("%5.4f", lineTotal / 60.0);
        else
            time.sprintf("%d:%02d", lineTotal / 60, lineTotal % 60);
        s += time;
        s += "</td>";

        s += "</tr>"; 
    }

    s += "<tr>";
    s += "<td colspan=2 bgcolor=" + QString(HEADER_BGCOLOR) + ">" +
         tr("Period Totals") + "</td>";
    int lineTotal = 0;
    for(unsigned int i = 0; i < document->activityCategories.count(); i++)
    {
        s += "<td align=center bgcolor=" + QString(TOTALS_BGCOLOR) + ">";
        QString time;
        lineTotal += categoryPeriodTotals[i];
        if (decimalHours)
            time.sprintf("%5.4f", categoryPeriodTotals[i] / 60.0);
        else
            time.sprintf("%d:%02d", categoryPeriodTotals[i] / 60,
                     categoryPeriodTotals[i] % 60);
         s += time;
         s += "</td>";
    }

    s += "<td align=center bgcolor=" + QString(TOTALS_BGCOLOR) + ">";
    QString time;
    if (decimalHours)
        time.sprintf("%5.4f", lineTotal / 60.0);
    else
        time.sprintf("%d:%02d", lineTotal / 60, lineTotal % 60);
    s += time;
    s += "</td>";

    s += "</tr>"; 
    s += "</table>";

    if (categoryDayTotals)
        delete[] categoryDayTotals;
    if (categoryPeriodTotals)
        delete[] categoryPeriodTotals;

    if (showingDeleted)
    {
        s += "<p><font color=#ff0000>";
        s += tr("Activities and categories shown in<br>"
                "<i>red italics</i> are obsolete.");
        s += "</font></p>";
    }
    
    if (warnOpenTasks)
    {
        s += "<p><font color=#ff0000>";
        s += tr("There are <i>active</i> tasks in this time period<br>"
                "that are excluded from this report.");
        s += "</font></p>";
    }

    s += "</qt>";

    return s;
}

QString PeriodTimeSheetReport::getReportFileName()
{
    QDate now = TimeSleuthMainWindow::getTSTime().date();

    return tr("Timesheet %1").arg(TimeString::shortDate(now)); 
}

int PeriodTimeSheetReport::countNonzeroActivities(QDate d)
{
    int numNonzeroActivities = 0;

    QListIterator<Activity> ali(document->activities);
    for( ; ali.current(); ++ali)
    {
        Activity* activity = ali.current();
        bool openTasks = false;
        if(document->getActivityDuration(d, d, activity, &openTasks) > 0)
            numNonzeroActivities++;
    }
    return numNonzeroActivities;
}
