/*
 * $Id: PurgeTasks.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "PurgeTasks.h"
#include "TimeSleuthMainWindow.h"
#include "TimeSleuthDocument.h"

#include <qpe/datebookmonth.h>
#include <qpe/timestring.h>
#include <qtoolbutton.h>
#include <qpopupmenu.h>
#include <qgroupbox.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
#include <qmessagebox.h>
#include <qspinbox.h>
#include <qcheckbox.h>


PurgeTasks::PurgeTasks(QWidget* parent, const char* name, 
    bool modal, WFlags fl) : PurgeTasksBase(parent, name, modal, fl)
{
    setupTimes();
    setupDatePicker();

    connect(btnDate,SIGNAL(pressed()),this,SLOT(pickDate()));
    connect(spinHour, SIGNAL(valueChanged(int)), this, 
            SLOT(hourChanged(int)));
    connect(spinMinute, SIGNAL(valueChanged(int)), this, 
            SLOT(minuteChanged(int)));
    connect(radSpecified, SIGNAL(stateChanged(int)), this, 
            SLOT(specifiedStateChanged(int)));
    connect(chkPM, SIGNAL(stateChanged(int)), this, 
            SLOT(pmChanged(int)));
}

PurgeTasks::~PurgeTasks()
{
}

void PurgeTasks::accept()
{
    qDebug("PurgeTasks::accept()");

    if (radNow->isChecked())
        dateTime = TimeSleuthMainWindow::getTSTime();

    PurgeTasksBase::accept();
}

QDateTime PurgeTasks::getDateTime() 
{
    return dateTime;
}

void PurgeTasks::setupDatePicker()
{
    popup = new QPopupMenu( this );
    picker = new DateBookMonth( popup, 0, TRUE );
    popup->insertItem( picker );
}

void PurgeTasks::pmChanged(int state)
{
    TimeSleuthDocument* document = ((TimeSleuthMainWindow*)parent())->document;
    if (document->configuration.twelveHourClock())
    {
        int hour;
        if (state)
        {
            // PM
            hour = (spinHour->value() == 12) ? 12 : 
                    spinHour->value() + 12;
        }
        else
        {
            // AM
            hour = (spinHour->value() == 12) ? 0 : 
                    spinHour->value();
        }
        dateTime = QDateTime(dateTime.date(), 
                              QTime(hour, dateTime.time().minute()));
    }
}

void PurgeTasks::specifiedStateChanged(int state)
{
    if (state)
    {
        btnDate->setEnabled(true);
        spinHour->setEnabled(true);
        spinMinute->setEnabled(true);
        chkPM->setEnabled(true);
    }
    else
    {
        btnDate->setEnabled(false);
        spinHour->setEnabled(false);
        spinMinute->setEnabled(false);
        chkPM->setEnabled(false);
    }
}

void PurgeTasks::hourChanged(int value)
{
    TimeSleuthDocument* document = ((TimeSleuthMainWindow*)parent())->document;
    int hour;
    if (document->configuration.twelveHourClock())
    {
        if (chkPM->isChecked())
        {
            // PM
            hour = (value == 12) ? 12 : value + 12;
        }
        else
        {
            // AM
            hour = (value == 12) ? 0 : value;
        }
    }
    else
    {
        hour = value;
        if (value < 10)
            spinHour->setPrefix("0");
        else
            spinHour->setPrefix("");
    }

    dateTime = QDateTime(dateTime.date(), 
                         QTime(hour, dateTime.time().minute()));
}

void PurgeTasks::minuteChanged(int value)
{
    dateTime = QDateTime(dateTime.date(), 
                         QTime(dateTime.time().hour(), value));
    if (value < 10)
        spinMinute->setPrefix("0");
    else
        spinMinute->setPrefix("");
}

void PurgeTasks::setupTimes()
{
   QDateTime now = TimeSleuthMainWindow::getTSTime();
   setDateTime(now);
}


void PurgeTasks::pickDate()
{
    picker->disconnect();
    popup->disconnect();
    connect( picker, SIGNAL( dateClicked( int, int, int ) ),
        this, SLOT( setDate( int, int, int ) ) );
    connect( popup, SIGNAL( aboutToHide() ),
        this, SLOT( gotHideDate() ) );
    picker->setDate(dateTime.date());
    popup->popup(mapToGlobal(btnDate->pos()+QPoint(0,btnDate->height()*3/2)));
    picker->setFocus();
}

void PurgeTasks::setDateTime(QDateTime dt)
{
    TimeSleuthDocument* document = ((TimeSleuthMainWindow*)parent())->document;
    dt = dt.isValid() ? dt : TimeSleuthMainWindow::getTSTime();
    btnDate->setText(TimeString::shortDate(dt.date()));
    if (document->configuration.twelveHourClock())
    {
        chkPM->show();
        if (dt.time().hour() >= 12)
            chkPM->setChecked(true);
        else
            chkPM->setChecked(false);
        spinHour->setPrefix("");
        spinHour->setValue((dt.time().hour() % 12) == 0 ? 12 :
                                (dt.time().hour() % 12));
        spinHour->setMinValue(1);
        spinHour->setMaxValue(12);
    }
    else
    {
        chkPM->hide();
        if (dt.time().hour() < 10)
            spinHour->setPrefix("0");
        else
            spinHour->setPrefix("");
        spinHour->setValue(dt.time().hour());
        spinHour->setMinValue(0);
        spinHour->setMaxValue(23);
    }

    if (dt.time().minute() < 10)
        spinMinute->setPrefix("0");
    else
        spinMinute->setPrefix("");
    spinMinute->setValue(dt.time().minute());

    dateTime = dt;
}

void PurgeTasks::setDate( int y, int m, int d )
{
    dateTime.setDate(QDate(y, m, d));
    btnDate->setText(TimeString::shortDate(dateTime.date()));
}

void PurgeTasks::gotHideDate()
{
    btnDate->setDown( false );
}

