/*
 * $Id: ReportParams1.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "ReportParams1.h"
#include "TimeSleuthMainWindow.h"

#include <qpe/datebookmonth.h>
#include <qpe/timestring.h>
#include <qtoolbutton.h>
#include <qpopupmenu.h>
#include <qgroupbox.h>
#include <qbuttongroup.h>
#include <qmessagebox.h>
#include <qcheckbox.h>


ReportParams1::ReportParams1(QWidget* parent, const char* name, 
    bool modal, WFlags fl) : ReportParams1Base(parent, name, modal, fl)
{
    setupTimes();
    setupDatePicker();

    connect(btnFromDate,SIGNAL(pressed()),this,SLOT(pickFromDate()));
    connect(btnToDate,SIGNAL(pressed()),this,SLOT(pickToDate()));
}

ReportParams1::~ReportParams1()
{
}

QDate ReportParams1::getFromDate() 
{
    return fromDate;
}

QDate ReportParams1::getToDate() 
{
    return toDate;
}

void ReportParams1::setupDatePicker()
{
    popup = new QPopupMenu( this );
    picker = new DateBookMonth( popup, 0, TRUE );
    popup->insertItem( picker );
}

void ReportParams1::setupTimes()
{
   QDate now = TimeSleuthMainWindow::getTSTime().date();
   setFromDate(now);
   setToDate(now);
}

/*
 * Override accept() virtual function to perform validation
 */
void ReportParams1::accept()
{
    if (fromDate > toDate)
    {
        QMessageBox::warning(this, 
            tr("Date Validation Error"),
            tr("From date cannot be\n"
            "after To date."),
        QMessageBox::Ok, 0);
        return;
    }
    
    ReportParams1Base::accept();
}

void ReportParams1::pickFromDate()
{
    qDebug("ReportParams1::pickFromDate()");
    picker->disconnect();
    popup->disconnect();
    connect( picker, SIGNAL( dateClicked( int, int, int ) ),
        this, SLOT( setFromDate( int, int, int ) ) );
    connect( popup, SIGNAL( aboutToHide() ),
        this, SLOT( gotHideFromDate() ) );
    picker->setDate(fromDate);
    popup->popup(mapToGlobal(btnFromDate->pos()+QPoint(0,
                             btnFromDate->height()*3/2)));
    picker->setFocus();
}

void ReportParams1::pickToDate()
{
    qDebug("ReportParams1::pickToDate()");
    picker->disconnect();
    popup->disconnect();
    connect( picker, SIGNAL( dateClicked( int, int, int ) ),
            this, SLOT( setToDate( int, int, int ) ) );
    connect( popup, SIGNAL( aboutToHide() ),
            this, SLOT( gotHideToDate() ) );
    picker->setDate(toDate);
    popup->popup(mapToGlobal(btnToDate->pos()+QPoint(0,
                             btnToDate->height()*3/2)));
    picker->setFocus();
}

void ReportParams1::setFromDate(QDate dt)
{
    dt = dt.isValid() ? dt : TimeSleuthMainWindow::getTSTime().date();
    btnFromDate->setText(TimeString::longDateString(dt));
    fromDate = dt;
}

void ReportParams1::setToDate(QDate dt)
{
    dt = dt.isValid() ? dt : TimeSleuthMainWindow::getTSTime().date();
    btnToDate->setText(TimeString::longDateString(dt));
    toDate = dt;
}

void ReportParams1::setFromDate( int y, int m, int d )
{
    fromDate.setYMD(y, m, d);
    btnFromDate->setText(TimeString::longDateString(fromDate));
}

void ReportParams1::setToDate( int y, int m, int d )
{
    toDate.setYMD(y, m, d);
    btnToDate->setText(TimeString::longDateString(toDate));
}

void ReportParams1::gotHideFromDate()
{
    btnFromDate->setDown( false );
}

void ReportParams1::gotHideToDate()
{
    btnToDate->setDown( false );
}

