/*
 * $Id: TSTable.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "TSTable.h"

#include <qevent.h>
#include <qnamespace.h>

TSTable::TSTable(QWidget* parent, const char* name) :
    QTable(parent, name)
{
    enablePainting = true;

    connect(this, SIGNAL(clicked(int,int,int,const QPoint&)), this,
            SLOT(mouseClicked(int,int,int,const QPoint&)));
}

TSTable::~TSTable()
{
    clear();
}

void TSTable::paintEvent(QPaintEvent* pe)
{
    if ( enablePainting )
        QTable::paintEvent( pe );
}

void TSTable::viewportPaintEvent( QPaintEvent *pe )
{
    if ( enablePainting )
        QTable::viewportPaintEvent( pe );
}

void TSTable::setPaintingEnabled( bool e )
{
    if ( e != enablePainting ) 
    {
        if ( !enablePainting ) 
        {
            enablePainting = true;
//            repaint();
//            viewport()->repaint();
            rowHeightChanged( 0 );
            viewport()->update();
        }
        else 
        {
            enablePainting = false;
        }
    }
}

void TSTable::clear()
{
    for ( int r = 0; r < numRows(); ++r ) 
    {
        for ( int c = 0; c < numCols(); ++c ) 
        {
            if ( cellWidget( r, c ) )
                clearCellWidget( r, c );
            clearCell( r, c );
        }
    }
    setNumRows( 0 );
}

void TSTable::rowHeightChanged( int row )
{
    if ( enablePainting )
        QTable::rowHeightChanged( row );
}

void TSTable::keyPressEvent(QKeyEvent* e)
{
    if (e->key() == Qt::Key_Space)
    {
        emit ok();
    }
    else
    {
        QTable::keyPressEvent(e);
    }
}

void TSTable::mouseClicked(int row, int col, int button, 
                           const QPoint& mousePos)
{
    if (row >= 0 && col >= 0)
        emit ok();
}
