/*
 * $Id: Task.cpp,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#include "Task.h"
#include "Activity.h"
#include "TimeSleuthMainWindow.h"
#include "Configuration.h"

#include <qpe/timestring.h>

TSTask::TSTask() : QObject(), id(0), shortcutPos(0), activity(0), 
    inDatabase(false) 
{
    #ifndef NO_DEBUG
        qDebug("New Task object created");
    #endif

    setStart(QDateTime());
    setStop(QDateTime());
}

TSTask::TSTask(int i_id, QDateTime i_start, QDateTime i_stop, int i_shortcutPos,
    Activity* i_activity, QDateTime i_lastModified, bool i_inDatabase) :
    id(i_id), shortcutPos(i_shortcutPos),
    activity(i_activity), inDatabase(i_inDatabase), 
    lastModified(i_lastModified)
{
    #ifndef NO_DEBUG
        qDebug("New Task object created");
    #endif

    setStart(i_start);
    setStop(i_stop);
}

TSTask::~TSTask()
{
    #ifndef NO_DEBUG
        qDebug("Task object destroyed");
    #endif
}

int TSTask::operator<(TSTask& t)
{
    if (startTime != t.startTime)
        return (startTime < t.startTime);
    
    return activity->name.compare(t.activity->name) < 0;
}

int TSTask::operator==(TSTask& t)
{
    if (startTime != t.startTime)
        return false;

    return activity->name.compare(t.activity->name) == 0;
}

/*
 * Returns the task duration in minutes for a closed
 * task.  Behavior is undefined for active tasks.
 */
int TSTask::duration()
{
    return startTime.secsTo(stopTime) / 60;
}

void TSTask::modified()
{
    if (inDatabase)
    {
        QDateTime timestamp = QDateTime::currentDateTime();
        if (!lastModified.isValid() || timestamp > lastModified)
        {
            // Update last modified time to now.
            lastModified = timestamp;
        }
        else
        {
            // This case should theoretically never happen, but could
            // happen if the RTC time is inaccurate.
            lastModified.addSecs(1);
        }
    }
}

QDateTime TSTask::start()
{
    return startTime;
}

QDateTime TSTask::stop()
{
    return stopTime;
}

void TSTask::setStart(QDateTime start)
{
    startTime = start;
    if (start.isValid())
    {
        startString = QString("%1 %2").arg(TimeString::shortDate(start.date()))
                                      .arg(TimeString::timeString(start.time(),
                                     Configuration::twelveHourClock(), false));
    }
    else
        startString = "";
}

void TSTask::setStop(QDateTime stop)
{
    stopTime = stop;
    if (stop.isValid())
    {
        stopString = QString("%1 %2").arg(TimeString::shortDate(stop.date()))
                                      .arg(TimeString::timeString(stop.time(),
                                    Configuration::twelveHourClock(), false));
    }
    else
        stopString = "";
}
