/*
 * $Id: TaskEdit.h,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#ifndef TASKEDIT_H
#define TASKEDIT_H

#include "TaskEditBase.h"
#include "TimeSleuthMainWindow.h"

#include <qdatetime.h>

class Activity;
class TimeSleuthDocument;
class QPopupMenu;
class DateBookMonth;

class TaskEdit : public TaskEditBase
{ 
    Q_OBJECT

public:
    TaskEdit(TSTask* t, QWidget* parent = 0, const char* name = 0, 
        bool modal = FALSE, WFlags fl = 0);
    ~TaskEdit();

    QDateTime now;  // Set (a) when TaskEdit is constructed, and (b)  when 
                    // 'ok' is clicked - caller of dialog should 
                    // use this value instead of QDateTime::currentDateTime
                    // or TimeSleuthMainWindow::getTSTime() to keep times 
                    // consistent.
    Activity* activity;
    TSTask* currentTask;

    QDateTime getStartDateTime();
    QDateTime getStopDateTime();
    
public slots:
    void setStartDateTime(QDateTime);
    void setStopDateTime(QDateTime);

private:
    void setupDatePicker();
    void setupTask();
    void setupTimes();
    void setupActivities();
    void setupBalloonTip();
    TimeSleuthDocument* document();
    QDateTime startDateTime;
    QDateTime stopDateTime;
    QPopupMenu *popup;
    DateBookMonth *picker;
    QList<Activity>* activeList;

private slots:
    void maintainActivities();
    void stopPMChanged(int state);
    void startPMChanged(int state);
    void startSpecifiedStateChanged(int state);
    void stopSpecifiedStateChanged(int state);
    void startHourChanged(int value);
    void startMinuteChanged(int value);
    void stopHourChanged(int value);
    void stopMinuteChanged(int value);
    void setStartDate(int y, int m, int d);
    void setStopDate(int y, int m, int d);
    void pickStartDate();
    void pickStopDate();
    void gotHideStartDate();
    void gotHideStopDate(); 
    void activityActivated(int);

protected slots:
    virtual void accept();
};

#endif // TASKEDIT_H
