/*
 * $Id: TimeSleuthDocument.h,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#ifndef TIMESLEUTHDOCUMENT_H
#define TIMESLEUTHDOCUMENT_H

#include "ActivityCategory.h"
#include "Activity.h"
#include "Task.h"
#include "Configuration.h"

#include <qobject.h>
#include <qsortedlist.h>
#include <qarray.h>

#define DOCUMENT_VERSION     105
#define NUM_TASK_SHORTCUTS   3
#define SYNC_TIMEOUT         60000

class TimeSleuthDocument : public QObject 
{
    Q_OBJECT
public:
    TimeSleuthDocument();
    ~TimeSleuthDocument();

    Configuration configuration;
    QSortedList<Activity> activities;
    QSortedList<ActivityCategory> activityCategories;
    QSortedList<TSTask> tasks;
    QArray<int> deletedTasks;
     
    enum ValidationCode
    {
        NO_ERRORS = 0,
        STOP_BEFORE_START = 1,
        ZERO_TASK_DURATION = 2,
        TASKS_OVERLAP = 3
    };

    bool load();
    bool save();
    void clear();
    QString getDocumentString(); 
    bool populateFromByteArray(char* dt, int len);
    void createSampleData();
    int allocateId();
    int getActivityDuration(QDate fromDate, QDate toDate, Activity* activity, 
                            bool* openTasks);
    ValidationCode validateTask(QDateTime start, QDateTime stop, 
                                QDateTime now, TSTask* currentTask);
    bool activeTasks();
    void includeShortcut(TSTask* taskToAdd);
    void removeTask(TSTask* task);
    void stopTask(TSTask* t, QDateTime now);
    int getNumActiveActivities(bool includeThoseWithTasks = false);
    int getNumActiveCategories();
    bool hasActivityGotTasks(Activity* a);

private:
    void removeObsoleteActivitiesAndCategories();
    void skipControlCharacters(char**, int*);
    int readInt(char**, int*);
    QString readString(char**, int*);
    int nextId;
};

#endif
