/*
 * $Id: TimeSleuthMainWindow.h,v 1.1 2002/10/31 20:06:18 robert Exp $
 *
 * Copyright (C) 2002 Dafydd Walters <dwalters@users.sourceforge.net>
 * 
 * This program may be modified or redistributed under the terms of the GNU
 * General Public License (GPL), version 2 or later. A copy of the GNU GPL 
 * should have accompanied the source code of this program. If not, please 
 * write to the Free Software Foundation Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * This program is distributed without any warranty.
 */ 

#ifndef TIMESLEUTHMAINWINDOW_H
#define TIMESLEUTHMAINWINDOW_H

#include "Report.h"

#include <qmainwindow.h>
#include <qdatetime.h>
#include <qaction.h>

class QToolBar;
class MainWidget;
class TimeSleuthDocument;
class TSTask;
class QTimer;
class QPopupMenu;
class QAction;
class QToolButton;
class DocLnk;

class TimeSleuthMainWindow : public QMainWindow
{
    Q_OBJECT

public:
    TimeSleuthMainWindow();
    ~TimeSleuthMainWindow();

    TimeSleuthDocument* document;
    static QDateTime getTSTime(bool withSeconds = false);
    static QString shortDate(QDate dt);
    static QString timeString(QTime, bool, bool);
    static QString longDateString(QDate);
    
public slots:
    void flush();
    void reload();
    void setDocument(const QString& applnk_filename);

private slots:
    void viewSavedReport();
    void syncServer();
    void maintainCategories();
    void maintainActivities();
    void operatingMode();
    void purge();
    void taskChanged();
    void newTask();
    void deleteTask();
    void editTask();
    void shortcut1Toggled(int);
    void shortcut2Toggled(int);
    void shortcut3Toggled(int);
    void concurrentToggled(bool);
    
private:
    void disableButtons();
    void enableButtons();
    void showDocument(const DocLnk&);
    void setupReports();
    void showBalloonTips();
    void addSettingsMenuItems(QPopupMenu* settingsMenu);
    void addTaskMenuItems(QPopupMenu* taskMenu, QPopupMenu* contextMenu,
                          QToolBar* bar);
    void addReportMenuItems(QPopupMenu* menu);
    void shortcutToggled(int pos, int state, QToolButton* button);
    void setupTimer();
    void setupDocument();
    void setupMenuBar();
    void promptUserMode();
    void updateView(TSTask*t = 0);
    bool getServerSettings();
    void setupCentralWidget();
    void updateControls();
    bool stopOtherTasks(TSTask*, QDateTime, bool updateStoppedTasks = false);
    void resetBalloonTips();

    MainWidget* view;
    QTimer* timer;
    QAction* newAction;
    QAction* editAction;
    QAction* deleteAction;
    QAction* viewSavedReportAction;
    QPopupMenu *contextMenu;
    QAction* allowConcurrentTasksAction;
    QAction* activitiesAction;
    QAction* categoriesAction;
    QAction* operatingModeAction;
    QAction* purgeAction;
    QAction* syncAction;
    
    // Reports
    QList<Report> reports;
};

#endif

